@@ -88,7 +88,7 @@ def get_virsorter_hits(virsorter_affi_contigs):
     raw_file = open(virsorter_affi_contigs).read()
 
     virsorter_rows = list()
-    for entry in raw_file.split('>')[1:]:
+    for entry in raw_file[1:].split('\n>'):
         split_entry = entry.strip().split('\n')
         entry_data = split_entry[0].split('|')
         entry_name = entry_data[0]
@@ -232,9 +232,9 @@ def get_metabolic_flags(annotations, metabolic_genes, amgs, verified_amgs, scaff
     flag_dict = dict()
     metabolic_genes = set(metabolic_genes)
     for scaffold, scaffold_annotations in annotations.groupby('scaffold'):
-        perc_xh = sum(['Xh' in i if not pd.isna(i) else False for i in scaffold_annotations['vogdb_categories']]) \
-                  / scaffold_annotations.shape[0]
-        is_j = perc_xh >= 0.18
+        # perc_xh = sum([i == 'Xh' if not pd.isna(i) else False for i in scaffold_annotations['vogdb_categories']]) \
+        #           / scaffold_annotations.shape[0]
+        # is_j = perc_xh >= 0.18
         for gene, row in scaffold_annotations.iterrows():
             # set up
             flags = ''
@@ -267,8 +267,8 @@ def get_metabolic_flags(annotations, metabolic_genes, amgs, verified_amgs, scaff
             if (int(row['start_position']) < length_from_end) or \
                (int(row['end_position']) > (scaffold_length_dict[row['scaffold']] - length_from_end)):
                 flags += 'F'
-            if is_j:
-                flags += 'J'
+            # if is_j:
+            #     flags += 'J'
             flag_dict[gene] = flags
         # get 3 metabolic genes in a row flag
         for i in range(len(scaffold_annotations)):  # this needs to be fixed. Will only give B to middle of 3 genes.
@@ -308,7 +308,7 @@ def get_virsorter_affi_contigs_name(scaffold):
     return virsorter_scaffold_name
 
 
-def annotate_vgfs(input_fasta, virsorter_affi_contigs=None, output_dir='.', min_contig_size=5000,
+def annotate_vgfs(input_fasta, virsorter_affi_contigs=None, output_dir='.', min_contig_size=2500,
                   bit_score_threshold=60, rbh_bit_score_threshold=350, custom_db_name=(), custom_fasta_loc=(),
                   use_uniref=False, low_mem_mode=False, skip_trnascan=False, keep_tmp_dir=True,
                   threads=10, verbose=True):
@@ -346,9 +346,10 @@ def annotate_vgfs(input_fasta, virsorter_affi_contigs=None, output_dir='.', min_
             contig_locs.append(contig_loc)
 
     # annotate vMAGs
+    rename_bins = False
     annotations = annotate_fastas(contig_locs, output_dir, db_locs_anno, db_handler, min_contig_size,
                                   bit_score_threshold, rbh_bit_score_threshold, custom_db_name, custom_fasta_loc,
-                                  skip_trnascan, keep_tmp_dir, start_time, threads, verbose)
+                                  skip_trnascan, rename_bins, keep_tmp_dir, start_time, threads, verbose)
     print('%s: Annotations complete, processing annotations' % str(datetime.now() - start_time))
 
     # setting up scoring viral genes
