@@ -126,7 +126,9 @@ def write_summarized_genomes_to_xlsx(summarized_genomes, output_file):
 # TODO: add assembly stats like N50, longest contig, total assembled length etc
 def make_genome_stats(annotations, rrna_frame=None, trna_frame=None, groupby_column='fasta'):
     rows = list()
-    columns = ['genome', 'number of scaffolds']
+    columns = ['genome']
+    if 'scaffold' in annotations.columns:
+        columns.append('number of scaffolds')
     if 'bin_taxonomy' in annotations.columns:
         columns.append('taxonomy')
     if 'bin_completeness' in annotations.columns:
@@ -141,7 +143,9 @@ def make_genome_stats(annotations, rrna_frame=None, trna_frame=None, groupby_col
        and rrna_frame is not None and trna_frame is not None:
         columns.append('assembly quality')
     for genome, frame in annotations.groupby(groupby_column, sort=False):
-        row = [genome, len(set(frame['scaffold']))]
+        row = [genome]
+        if 'scaffold' in frame.columns:
+            row.append(len(set(frame['scaffold'])))
         if 'bin_taxonomy' in frame.columns:
             row.append(frame['bin_taxonomy'][0])
         if 'bin_completeness' in frame.columns:
@@ -533,7 +537,7 @@ def make_strings_no_repeats(genome_taxa_dict):
     return labels
 
 
-def summarize_genomes(input_file, trna_path, rrna_path, output_dir, groupby_column):
+def summarize_genomes(input_file, trna_path=None, rrna_path=None, output_dir='.', groupby_column='fasta'):
     start_time = datetime.now()
 
     # read in data
@@ -584,7 +588,13 @@ def summarize_genomes(input_file, trna_path, rrna_path, output_dir, groupby_colu
     # make liquor
     if 'bin_taxonomy' in annotations:
         genome_order = get_ordered_uniques(annotations.sort_values('bin_taxonomy')[groupby_column])
-        labels = make_strings_no_repeats({row[groupby_column]: get_phylum_and_most_specific(row['bin_taxonomy'])
+        # if gtdb format then get phylum and most specific
+        if all([i[:3] == 'd__' and len(i.split(';')) == 7 for i in annotations['bin_taxonomy']]):
+            taxa_str_parser = get_phylum_and_most_specific
+        # else just throw in what is there
+        else:
+            taxa_str_parser = lambda x: x
+        labels = make_strings_no_repeats({row[groupby_column]: taxa_str_parser(row['bin_taxonomy'])
                                           for _, row in annotations.iterrows()})
     else:
         genome_order = get_ordered_uniques(annotations.sort_values(groupby_column)[groupby_column])
@@ -611,17 +621,17 @@ def summarize_genomes(input_file, trna_path, rrna_path, output_dir, groupby_colu
             function_dfs.append(function_df_subset)
             liquor = make_liquor_heatmap(module_coverage_df_subset, etc_coverage_df_subset, function_df_subset,
                                          genomes, labels)
-            liquor.save(path.join(output_dir, 'liquor_%s.html' % i))
+            liquor.save(path.join(output_dir, 'product_%s.html' % i))
         liquor_df = make_liquor_df(pd.concat(module_coverage_dfs), pd.concat(etc_coverage_dfs), pd.concat(function_dfs))
-        liquor_df.to_csv(path.join(output_dir, 'liquor.tsv'), sep='\t')
+        liquor_df.to_csv(path.join(output_dir, 'product.tsv'), sep='\t')
     else:
         module_coverage_df, etc_coverage_df, function_df = fill_liquor_dfs(annotations, module_nets,
                                                                            etc_module_df,
                                                                            function_heatmap_form,
                                                                            groupby_column='fasta')
         liquor_df = make_liquor_df(module_coverage_df, etc_coverage_df, function_df)
-        liquor_df.to_csv(path.join(output_dir, 'liquor.tsv'), sep='\t')
+        liquor_df.to_csv(path.join(output_dir, 'product.tsv'), sep='\t')
         liquor = make_liquor_heatmap(module_coverage_df, etc_coverage_df, function_df, genome_order, labels)
-        liquor.save(path.join(output_dir, 'liquor.html'))
-    print('%s: Generated liquor heatmap and table' % (str(datetime.now() - start_time)))
+        liquor.save(path.join(output_dir, 'product.html'))
+    print('%s: Generated product heatmap and table' % (str(datetime.now() - start_time)))
     print("%s: Completed distillation" % str(datetime.now() - start_time))
