@@ -285,7 +285,7 @@ def test_assign_grades():
 def phix_annotations():
     return pd.DataFrame([['A', 'K1', 'U1', None, 'a_bug1'],
                          ['B', 'K2', 'U2', 'P2', 'a_bug2'],
-                         ['C', 'K3', 'U3', 'P3', 'a_bug3'],
+                         ['C', None, 'U3', 'P3', 'a_bug3'],
                          ['D', 'K4', 'U4', 'P4', 'a_bug4'],
                          ['A', 'K5', 'U5', 'P5', 'a_bug5'],
                          ['E', 'K6', 'U6', 'P6', 'a_bug6'],
@@ -305,6 +305,33 @@ def test_generate_annotated_fasta_short(phix_prodigal_genes, phix_annotations):
     assert short_fasta_header_dict['phiX_NC_001422.1_4'] == 'rank: D; P4 (db=pfam)'
 
 
+@pytest.fixture()
+def phix_annotations_no_kegg():
+    return pd.DataFrame([['B', 'U1', None, 'a_bug1'],
+                         ['B', 'U2', 'P2', 'a_bug2'],
+                         ['C', 'U3', 'P3', 'a_bug3'],
+                         ['D', 'U4', 'P4', 'a_bug4'],
+                         ['B', 'U5', 'P5', 'a_bug5'],
+                         ['E', 'U6', 'P6', 'a_bug6'],
+                         ['C', 'U7', 'P7', 'a_bug7']],
+                        index=['NC_001422.1_1', 'NC_001422.1_2', 'NC_001422.1_3', 'NC_001422.1_4', 'NC_001422.1_5',
+                               'NC_001422.1_6', 'NC_001422.1_7'],
+                        columns=['rank', 'uniref_hit', 'pfam_hits', 'bin_taxonomy'])
+
+
+def test_generate_annotated_fasta_short_no_kegg(phix_prodigal_genes, phix_annotations_no_kegg):
+    # drop kegg hit column
+    fasta_generator_short_no_kegg = generate_annotated_fasta(phix_prodigal_genes, phix_annotations_no_kegg,
+                                                             verbosity='short', name='phiX')
+    short_fasta_header_dict_no_kegg = {seq.metadata['id']: seq.metadata['description']
+                                       for seq in fasta_generator_short_no_kegg}
+    print(short_fasta_header_dict_no_kegg)
+
+    assert short_fasta_header_dict_no_kegg['phiX_NC_001422.1_1'] == 'rank: B; U1 (db=uniref)'
+    assert short_fasta_header_dict_no_kegg['phiX_NC_001422.1_2'] == 'rank: B; U2 (db=uniref)'
+    assert short_fasta_header_dict_no_kegg['phiX_NC_001422.1_4'] == 'rank: D; P4 (db=pfam)'
+
+
 def test_generate_annotated_fasta_long(phix_prodigal_genes, phix_annotations):
     fasta_generator_long = generate_annotated_fasta(phix_prodigal_genes, phix_annotations, verbosity='long',
                                                     name='phiX')
